@@ -74,8 +74,10 @@
 #define YYERROR_VERBOSE
 
 static dictServer *s;
+extern int yylex(void);
+extern void yyerror(const char *message);
 
-#line 79 "y.tab.c"
+#line 81 "y.tab.c"
 
 # ifndef YY_CAST
 #  ifdef __cplusplus
@@ -142,12 +144,12 @@ extern int yydebug;
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 union YYSTYPE
 {
-#line 29 "clientparse.y"
+#line 31 "clientparse.y"
 
    dictToken     token;
    lst_List      list;
 
-#line 151 "y.tab.c"
+#line 153 "y.tab.c"
 
 };
 typedef union YYSTYPE YYSTYPE;
@@ -570,8 +572,8 @@ static const yytype_int8 yytranslate[] =
 /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_int8 yyrline[] =
 {
-       0,    43,    43,    46,    47,    51,    50,    57,    66,    67,
-      70,    71
+       0,    45,    45,    48,    49,    53,    52,    59,    68,    69,
+      72,    73
 };
 #endif
 
@@ -1139,58 +1141,58 @@ yyreduce:
   switch (yyn)
     {
   case 3: /* ServerList: Server  */
-#line 46 "clientparse.y"
+#line 48 "clientparse.y"
                     { (yyval.list) = dict_Servers = lst_create(); lst_append((yyval.list), (yyvsp[0].list)); }
-#line 1145 "y.tab.c"
+#line 1147 "y.tab.c"
     break;
 
   case 4: /* ServerList: ServerList Server  */
-#line 47 "clientparse.y"
+#line 49 "clientparse.y"
                                { lst_append((yyvsp[-1].list), (yyvsp[0].list)); (yyval.list) = (yyvsp[-1].list); }
-#line 1151 "y.tab.c"
+#line 1153 "y.tab.c"
     break;
 
   case 5: /* $@1: %empty  */
-#line 51 "clientparse.y"
+#line 53 "clientparse.y"
            {
 	      s = xmalloc(sizeof(struct dictServer));
 	      memset( s, 0, sizeof(struct dictServer));
 	      s->host = (yyvsp[0].token).string;
 	   }
-#line 1161 "y.tab.c"
+#line 1163 "y.tab.c"
     break;
 
   case 6: /* Server: TOKEN_SERVER TOKEN_STRING $@1 '{' SpecList '}'  */
-#line 56 "clientparse.y"
+#line 58 "clientparse.y"
                             { (yyval.list) = s; }
-#line 1167 "y.tab.c"
+#line 1169 "y.tab.c"
     break;
 
   case 7: /* Server: TOKEN_SERVER TOKEN_STRING  */
-#line 58 "clientparse.y"
+#line 60 "clientparse.y"
            {
 	      s = xmalloc(sizeof(struct dictServer));
 	      memset( s, 0, sizeof(struct dictServer));
 	      s->host = (yyvsp[0].token).string;
 	      (yyval.list) = s;
 	   }
-#line 1178 "y.tab.c"
+#line 1180 "y.tab.c"
     break;
 
   case 10: /* Spec: TOKEN_PORT TOKEN_STRING  */
-#line 70 "clientparse.y"
+#line 72 "clientparse.y"
                                         { s->port = (yyvsp[0].token).string; }
-#line 1184 "y.tab.c"
+#line 1186 "y.tab.c"
     break;
 
   case 11: /* Spec: TOKEN_USER TOKEN_STRING TOKEN_STRING  */
-#line 71 "clientparse.y"
+#line 73 "clientparse.y"
                                             { s->user = (yyvsp[-1].token).string; s->secret = (yyvsp[0].token).string; }
-#line 1190 "y.tab.c"
+#line 1192 "y.tab.c"
     break;
 
 
-#line 1194 "y.tab.c"
+#line 1196 "y.tab.c"
 
       default: break;
     }
