@@ -99,7 +99,11 @@ static int string2bool (const char *str)
    db->field = t.string;                                      \
 } while(0);
 
-#line 103 "y.tab.c"
+extern int yylex(void);
+extern void yyerror(const char *message);
+
+
+#line 107 "y.tab.c"
 
 # ifndef YY_CAST
 #  ifdef __cplusplus
@@ -266,7 +270,7 @@ extern int yydebug;
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 union YYSTYPE
 {
-#line 53 "servparse.y"
+#line 57 "servparse.y"
 
    dictToken     token;
    dictDatabase  *db;
@@ -274,7 +278,7 @@ union YYSTYPE
    lst_List      list;
    hsh_HashTable hash;
 
-#line 278 "y.tab.c"
+#line 282 "y.tab.c"
 
 };
 typedef union YYSTYPE YYSTYPE;
@@ -784,19 +788,19 @@ static const yytype_int8 yytranslate[] =
 /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_int16 yyrline[] =
 {
-       0,   116,   116,   121,   127,   133,   140,   146,   153,   160,
-     171,   172,   175,   176,   179,   184,   193,   198,   202,   206,
-     214,   221,   226,   231,   235,   239,   244,   248,   253,   260,
-     264,   269,   274,   278,   282,   288,   301,   305,   312,   318,
-     324,   328,   334,   337,   338,   341,   342,   345,   352,   356,
-     360,   367,   374,   381,   391,   390,   400,   399,   409,   408,
-     418,   417,   426,   437,   438,   441,   442,   443,   444,   445,
-     446,   449,   450,   453,   454,   457,   458,   459,   460,   461,
-     462,   463,   464,   467,   468,   469,   470,   471,   472,   473,
-     474,   477,   478,   481,   482,   483,   484,   485,   486,   487,
-     488,   489,   490,   491,   492,   493,   496,   499,   502,   505,
-     508,   511,   514,   517,   520,   523,   526,   529,   532,   535,
-     538
+       0,   120,   120,   125,   131,   137,   144,   150,   157,   164,
+     175,   176,   179,   180,   183,   188,   197,   202,   206,   210,
+     218,   225,   230,   235,   239,   243,   248,   252,   257,   264,
+     268,   273,   278,   282,   286,   292,   305,   309,   316,   322,
+     328,   332,   338,   341,   342,   345,   346,   349,   356,   360,
+     364,   371,   378,   385,   395,   394,   404,   403,   413,   412,
+     422,   421,   430,   441,   442,   445,   446,   447,   448,   449,
+     450,   453,   454,   457,   458,   461,   462,   463,   464,   465,
+     466,   467,   468,   471,   472,   473,   474,   475,   476,   477,
+     478,   481,   482,   485,   486,   487,   488,   489,   490,   491,
+     492,   493,   494,   495,   496,   497,   500,   503,   506,   509,
+     512,   515,   518,   521,   524,   527,   530,   533,   536,   539,
+     542
 };
 #endif
 
@@ -1515,79 +1519,79 @@ yyreduce:
   switch (yyn)
     {
   case 2: /* Program: Global DatabaseList  */
-#line 117 "servparse.y"
+#line 121 "servparse.y"
           { DictConfig = xmalloc(sizeof(struct dictConfig));
 	    memset( DictConfig, 0, sizeof(struct dictConfig) );
 	    DictConfig->dbl = (yyvsp[0].list);
 	  }
-#line 1524 "y.tab.c"
+#line 1528 "y.tab.c"
     break;
 
   case 3: /* Program: Global Access DatabaseList  */
-#line 122 "servparse.y"
+#line 126 "servparse.y"
           { DictConfig = xmalloc(sizeof(struct dictConfig));
 	    memset( DictConfig, 0, sizeof(struct dictConfig) );
 	    DictConfig->acl = (yyvsp[-1].list);
 	    DictConfig->dbl = (yyvsp[0].list);
 	  }
-#line 1534 "y.tab.c"
+#line 1538 "y.tab.c"
     break;
 
   case 4: /* Program: Global DatabaseList UserList  */
-#line 128 "servparse.y"
+#line 132 "servparse.y"
           { DictConfig = xmalloc(sizeof(struct dictConfig));
 	    memset( DictConfig, 0, sizeof(struct dictConfig) );
 	    DictConfig->dbl = (yyvsp[-1].list);
 	    DictConfig->usl = (yyvsp[0].hash);
 	  }
-#line 1544 "y.tab.c"
+#line 1548 "y.tab.c"
     break;
 
   case 5: /* Program: Global Access DatabaseList UserList  */
-#line 134 "servparse.y"
+#line 138 "servparse.y"
           { DictConfig = xmalloc(sizeof(struct dictConfig));
 	    memset( DictConfig, 0, sizeof(struct dictConfig) );
 	    DictConfig->acl = (yyvsp[-2].list);
 	    DictConfig->dbl = (yyvsp[-1].list);
 	    DictConfig->usl = (yyvsp[0].hash);
 	  }
-#line 1555 "y.tab.c"
+#line 1559 "y.tab.c"
     break;
 
   case 6: /* Program: Global Site DatabaseList  */
-#line 141 "servparse.y"
+#line 145 "servparse.y"
           { DictConfig = xmalloc(sizeof(struct dictConfig));
 	    memset( DictConfig, 0, sizeof(struct dictConfig) );
 	    site_info        = (yyvsp[-1].token).string;
 	    DictConfig->dbl  = (yyvsp[0].list);
 	  }
-#line 1565 "y.tab.c"
+#line 1569 "y.tab.c"
     break;
 
   case 7: /* Program: Global Site Access DatabaseList  */
-#line 147 "servparse.y"
+#line 151 "servparse.y"
           { DictConfig = xmalloc(sizeof(struct dictConfig));
 	    memset( DictConfig, 0, sizeof(struct dictConfig) );
 	    site_info        = (yyvsp[-2].token).string;
 	    DictConfig->acl  = (yyvsp[-1].list);
 	    DictConfig->dbl  = (yyvsp[0].list);
 	  }
-#line 1576 "y.tab.c"
+#line 1580 "y.tab.c"
     break;
 
   case 8: /* Program: Global Site DatabaseList UserList  */
-#line 154 "servparse.y"
+#line 158 "servparse.y"
           { DictConfig = xmalloc(sizeof(struct dictConfig));
 	    memset( DictConfig, 0, sizeof(struct dictConfig) );
 	    site_info        = (yyvsp[-2].token).string;
 	    DictConfig->dbl  = (yyvsp[-1].list);
 	    DictConfig->usl  = (yyvsp[0].hash);
 	  }
-#line 1587 "y.tab.c"
+#line 1591 "y.tab.c"
     break;
 
   case 9: /* Program: Global Site Access DatabaseList UserList  */
-#line 161 "servparse.y"
+#line 165 "servparse.y"
           { DictConfig = xmalloc(sizeof(struct dictConfig));
 	    memset( DictConfig, 0, sizeof(struct dictConfig) );
 	    site_info        = (yyvsp[-3].token).string;
@@ -1595,32 +1599,32 @@ yyreduce:
 	    DictConfig->dbl  = (yyvsp[-1].list);
 	    DictConfig->usl  = (yyvsp[0].hash);
 	  }
-#line 1599 "y.tab.c"
+#line 1603 "y.tab.c"
     break;
 
   case 10: /* Global: %empty  */
-#line 171 "servparse.y"
+#line 175 "servparse.y"
          {}
-#line 1605 "y.tab.c"
+#line 1609 "y.tab.c"
     break;
 
   case 11: /* Global: TOKEN_GLOBAL '{' GlobalSpecList '}'  */
-#line 172 "servparse.y"
+#line 176 "servparse.y"
                                              {}
-#line 1611 "y.tab.c"
+#line 1615 "y.tab.c"
     break;
 
   case 14: /* GlobalSpec: TOKEN_PORT TOKEN_STRING  */
-#line 180 "servparse.y"
+#line 184 "servparse.y"
      {
 	if (!daemon_service_set)
 	   daemon_service = str_copy((yyvsp[0].token).string);
      }
-#line 1620 "y.tab.c"
+#line 1624 "y.tab.c"
     break;
 
   case 15: /* GlobalSpec: TOKEN_SITE TOKEN_STRING  */
-#line 185 "servparse.y"
+#line 189 "servparse.y"
      {
 	if (site_info){
 	   /* site is specified twice */
@@ -1629,36 +1633,36 @@ yyreduce:
 
 	site_info = (yyvsp[0].token).string;
      }
-#line 1633 "y.tab.c"
+#line 1637 "y.tab.c"
     break;
 
   case 16: /* GlobalSpec: TOKEN_SITE_NO_BANNER TOKEN_STRING  */
-#line 194 "servparse.y"
+#line 198 "servparse.y"
      {
 	site_info_no_banner = string2bool ((yyvsp[0].token).string);
 	fprintf (stderr, "site_info_no_banner=%d\n", site_info_no_banner);
      }
-#line 1642 "y.tab.c"
+#line 1646 "y.tab.c"
     break;
 
   case 17: /* GlobalSpec: TOKEN_SITE_NO_UPTIME TOKEN_STRING  */
-#line 199 "servparse.y"
+#line 203 "servparse.y"
      {
 	site_info_no_uptime = string2bool ((yyvsp[0].token).string);
      }
-#line 1650 "y.tab.c"
+#line 1654 "y.tab.c"
     break;
 
   case 18: /* GlobalSpec: TOKEN_SITE_NO_DBLIST TOKEN_STRING  */
-#line 203 "servparse.y"
+#line 207 "servparse.y"
      {
 	site_info_no_dblist = string2bool ((yyvsp[0].token).string);
      }
-#line 1658 "y.tab.c"
+#line 1662 "y.tab.c"
     break;
 
   case 19: /* GlobalSpec: TOKEN_PORT TOKEN_NUMBER  */
-#line 207 "servparse.y"
+#line 211 "servparse.y"
      {
 	if (!daemon_service_set){
 	   char number [40] = "";
@@ -1666,145 +1670,145 @@ yyreduce:
 	   daemon_service = str_copy (number);
 	}
      }
-#line 1670 "y.tab.c"
+#line 1674 "y.tab.c"
     break;
 
   case 20: /* GlobalSpec: TOKEN_DELAY TOKEN_NUMBER  */
-#line 215 "servparse.y"
+#line 219 "servparse.y"
      {
 	if (!client_delay_set)
 	   client_delay = (yyvsp[0].token.integer);
 
 	_dict_daemon_limit_time = 0;
      }
-#line 1681 "y.tab.c"
+#line 1685 "y.tab.c"
     break;
 
   case 21: /* GlobalSpec: TOKEN_DEPTH TOKEN_NUMBER  */
-#line 222 "servparse.y"
+#line 226 "servparse.y"
      {
 	if (!depth_set)
 	   depth = (yyvsp[0].token.integer);
      }
-#line 1690 "y.tab.c"
+#line 1694 "y.tab.c"
     break;
 
   case 22: /* GlobalSpec: TOKEN_LIMIT_CHILDS TOKEN_NUMBER  */
-#line 227 "servparse.y"
+#line 231 "servparse.y"
      {
 	if (!_dict_daemon_limit_childs_set)
 	   _dict_daemon_limit_childs = (yyvsp[0].token.integer);
      }
-#line 1699 "y.tab.c"
+#line 1703 "y.tab.c"
     break;
 
   case 23: /* GlobalSpec: TOKEN_LIMIT_MATCHES TOKEN_NUMBER  */
-#line 232 "servparse.y"
+#line 236 "servparse.y"
      {
 	_dict_daemon_limit_matches = (yyvsp[0].token.integer);
      }
-#line 1707 "y.tab.c"
+#line 1711 "y.tab.c"
     break;
 
   case 24: /* GlobalSpec: TOKEN_LIMIT_DEFS TOKEN_NUMBER  */
-#line 236 "servparse.y"
+#line 240 "servparse.y"
      {
 	_dict_daemon_limit_defs = (yyvsp[0].token.integer);
      }
-#line 1715 "y.tab.c"
+#line 1719 "y.tab.c"
     break;
 
   case 25: /* GlobalSpec: TOKEN_LIMIT_TIME TOKEN_NUMBER  */
-#line 240 "servparse.y"
+#line 244 "servparse.y"
      {
 	_dict_daemon_limit_time = (yyvsp[0].token.integer);
 	client_delay            = 0;
      }
-#line 1724 "y.tab.c"
+#line 1728 "y.tab.c"
     break;
 
   case 26: /* GlobalSpec: TOKEN_LIMIT_QUERIES TOKEN_NUMBER  */
-#line 245 "servparse.y"
+#line 249 "servparse.y"
      {
 	_dict_daemon_limit_queries = (yyvsp[0].token.integer);
      }
-#line 1732 "y.tab.c"
+#line 1736 "y.tab.c"
     break;
 
   case 27: /* GlobalSpec: TOKEN_TIMESTAMP TOKEN_NUMBER  */
-#line 249 "servparse.y"
+#line 253 "servparse.y"
      {
 	if (!_dict_markTime_set)
 	   _dict_markTime = 60*(yyvsp[0].token.integer);
      }
-#line 1741 "y.tab.c"
+#line 1745 "y.tab.c"
     break;
 
   case 28: /* GlobalSpec: TOKEN_LOG_OPTION TOKEN_STRING  */
-#line 254 "servparse.y"
+#line 258 "servparse.y"
      {
 	 ++logOptions;
 	 flg_set ((yyvsp[0].token).string);
 	 if (flg_test (LOG_MIN))
 	    set_minimal ();
      }
-#line 1752 "y.tab.c"
+#line 1756 "y.tab.c"
     break;
 
   case 29: /* GlobalSpec: TOKEN_DEBUG_OPTION TOKEN_STRING  */
-#line 261 "servparse.y"
+#line 265 "servparse.y"
      {
 	dbg_set ((yyvsp[0].token).string);
      }
-#line 1760 "y.tab.c"
+#line 1764 "y.tab.c"
     break;
 
   case 30: /* GlobalSpec: TOKEN_LOCALE TOKEN_STRING  */
-#line 265 "servparse.y"
+#line 269 "servparse.y"
      {
 	if (!locale_set)
 	   locale = str_copy ((yyvsp[0].token).string);
      }
-#line 1769 "y.tab.c"
+#line 1773 "y.tab.c"
     break;
 
   case 31: /* GlobalSpec: TOKEN_DEFAULT_STRAT TOKEN_STRING  */
-#line 270 "servparse.y"
+#line 274 "servparse.y"
      {
 	if (!default_strategy_set)
 	   default_strategy     = lookup_strategy_ex ((yyvsp[0].token).string);
      }
-#line 1778 "y.tab.c"
+#line 1782 "y.tab.c"
     break;
 
   case 32: /* GlobalSpec: TOKEN_DISABLE_STRAT TOKEN_STRING  */
-#line 275 "servparse.y"
+#line 279 "servparse.y"
      {
 	dict_disable_strategies ((yyvsp[0].token).string);
      }
-#line 1786 "y.tab.c"
+#line 1790 "y.tab.c"
     break;
 
   case 33: /* GlobalSpec: TOKEN_ADD_STRAT TOKEN_STRING TOKEN_STRING  */
-#line 279 "servparse.y"
+#line 283 "servparse.y"
      {
 	dict_add_strategy ((yyvsp[-1].token).string, (yyvsp[0].token).string);
      }
-#line 1794 "y.tab.c"
+#line 1798 "y.tab.c"
     break;
 
   case 34: /* GlobalSpec: TOKEN_LISTEN_TO TOKEN_STRING  */
-#line 283 "servparse.y"
+#line 287 "servparse.y"
      {
 	if (!bind_to_set)
 	   if ((yyvsp[0].token).string[0] != '*' || (yyvsp[0].token).string[1] != '\0')
 	      bind_to = str_copy ((yyvsp[0].token).string);
      }
-#line 1804 "y.tab.c"
+#line 1808 "y.tab.c"
     break;
 
   case 35: /* GlobalSpec: TOKEN_ADDRESS_FAMILY TOKEN_NUMBER  */
-#line 289 "servparse.y"
+#line 293 "servparse.y"
      {
 	if (!dictd_address_family_set){
 	   if ((yyvsp[0].token.integer) == 4)
@@ -1817,231 +1821,231 @@ yyreduce:
 	   }
 	}
      }
-#line 1821 "y.tab.c"
+#line 1825 "y.tab.c"
     break;
 
   case 36: /* GlobalSpec: TOKEN_SYSLOG  */
-#line 302 "servparse.y"
+#line 306 "servparse.y"
      {
 	++useSyslog;
      }
-#line 1829 "y.tab.c"
+#line 1833 "y.tab.c"
     break;
 
   case 37: /* GlobalSpec: TOKEN_SYSLOG_FACILITY TOKEN_STRING  */
-#line 306 "servparse.y"
+#line 310 "servparse.y"
      {
 	++useSyslog;
 	if (!syslog_facility_set){
 	   log_set_facility ((yyvsp[0].token).string);
 	}
      }
-#line 1840 "y.tab.c"
+#line 1844 "y.tab.c"
     break;
 
   case 38: /* GlobalSpec: TOKEN_LOG_FILE TOKEN_STRING  */
-#line 313 "servparse.y"
+#line 317 "servparse.y"
      {
 	if (!logFile_set){
 	   logFile     = str_copy ((yyvsp[0].token).string);
 	}
      }
-#line 1850 "y.tab.c"
+#line 1854 "y.tab.c"
     break;
 
   case 39: /* GlobalSpec: TOKEN_PID_FILE TOKEN_STRING  */
-#line 319 "servparse.y"
+#line 323 "servparse.y"
      {
 	if (!pidFile_set){
 	   pidFile     = str_copy ((yyvsp[0].token).string);
 	}
      }
-#line 1860 "y.tab.c"
+#line 1864 "y.tab.c"
     break;
 
   case 40: /* GlobalSpec: TOKEN_FAST_START  */
-#line 325 "servparse.y"
+#line 329 "servparse.y"
      {
 	optStart_mode = 0;
      }
-#line 1868 "y.tab.c"
+#line 1872 "y.tab.c"
     break;
 
   case 41: /* GlobalSpec: TOKEN_WITHOUT_MMAP  */
-#line 329 "servparse.y"
+#line 333 "servparse.y"
      {
 	mmap_mode = 0;
      }
-#line 1876 "y.tab.c"
+#line 1880 "y.tab.c"
     break;
 
   case 42: /* Access: TOKEN_ACCESS '{' AccessSpecList '}'  */
-#line 334 "servparse.y"
+#line 338 "servparse.y"
                                              { (yyval.list) = (yyvsp[-1].list); }
-#line 1882 "y.tab.c"
+#line 1886 "y.tab.c"
     break;
 
   case 43: /* DatabaseList: Database  */
-#line 337 "servparse.y"
+#line 341 "servparse.y"
                         { (yyval.list) = lst_create(); lst_append((yyval.list), (yyvsp[0].db)); }
-#line 1888 "y.tab.c"
+#line 1892 "y.tab.c"
     break;
 
   case 44: /* DatabaseList: DatabaseList Database  */
-#line 338 "servparse.y"
+#line 342 "servparse.y"
                                      { lst_append((yyvsp[-1].list), (yyvsp[0].db)); (yyval.list) = (yyvsp[-1].list); }
-#line 1894 "y.tab.c"
+#line 1898 "y.tab.c"
     break;
 
   case 45: /* AccessSpecList: AccessSpec  */
-#line 341 "servparse.y"
+#line 345 "servparse.y"
                             { (yyval.list) = lst_create(); lst_append((yyval.list), (yyvsp[0].access)); }
-#line 1900 "y.tab.c"
+#line 1904 "y.tab.c"
     break;
 
   case 46: /* AccessSpecList: AccessSpecList AccessSpec  */
-#line 342 "servparse.y"
+#line 346 "servparse.y"
                                            { lst_append((yyvsp[-1].list), (yyvsp[0].access)); (yyval.list) = (yyvsp[-1].list); }
-#line 1906 "y.tab.c"
+#line 1910 "y.tab.c"
     break;
 
   case 47: /* Site: TOKEN_SITE TOKEN_STRING  */
-#line 346 "servparse.y"
+#line 350 "servparse.y"
        {
 	  (yyval.token) = (yyvsp[0].token);
 	  log_error (NULL, ":E: Move \"site\" directive to section \"global\" of the configuration file!\n");
        }
-#line 1915 "y.tab.c"
+#line 1919 "y.tab.c"
     break;
 
   case 48: /* UserList: TOKEN_USER TOKEN_STRING TOKEN_STRING  */
-#line 353 "servparse.y"
+#line 357 "servparse.y"
            { (yyval.hash) = hsh_create(NULL,NULL);
 	     hsh_insert( (yyval.hash), (yyvsp[-1].token).string, (yyvsp[0].token).string );
 	   }
-#line 1923 "y.tab.c"
+#line 1927 "y.tab.c"
     break;
 
   case 49: /* UserList: UserList TOKEN_USER TOKEN_STRING TOKEN_STRING  */
-#line 357 "servparse.y"
+#line 361 "servparse.y"
            { hsh_insert( (yyvsp[-3].hash), (yyvsp[-1].token).string, (yyvsp[0].token).string ); (yyval.hash) = (yyvsp[-3].hash); }
-#line 1929 "y.tab.c"
+#line 1933 "y.tab.c"
     break;
 
   case 50: /* AccessSpec: TOKEN_ALLOW TOKEN_STRING  */
-#line 361 "servparse.y"
+#line 365 "servparse.y"
              {
 		dictAccess *a = xmalloc(sizeof(struct dictAccess));
 		a->type = DICT_ALLOW;
 		a->spec = (yyvsp[0].token).string;
 		(yyval.access) = a;
 	     }
-#line 1940 "y.tab.c"
+#line 1944 "y.tab.c"
     break;
 
   case 51: /* AccessSpec: TOKEN_DENY TOKEN_STRING  */
-#line 368 "servparse.y"
+#line 372 "servparse.y"
              {
 		dictAccess *a = xmalloc(sizeof(struct dictAccess));
 		a->type = DICT_DENY;
 		a->spec = (yyvsp[0].token).string;
 		(yyval.access) = a;
 	     }
-#line 1951 "y.tab.c"
+#line 1955 "y.tab.c"
     break;
 
   case 52: /* AccessSpec: TOKEN_AUTHONLY TOKEN_STRING  */
-#line 375 "servparse.y"
+#line 379 "servparse.y"
              {
 		dictAccess *a = xmalloc(sizeof(struct dictAccess));
 		a->type = DICT_AUTHONLY;
 		a->spec = (yyvsp[0].token).string;
 		(yyval.access) = a;
 	     }
-#line 1962 "y.tab.c"
+#line 1966 "y.tab.c"
     break;
 
   case 53: /* AccessSpec: TOKEN_USER TOKEN_STRING  */
-#line 382 "servparse.y"
+#line 386 "servparse.y"
              {
 		dictAccess *a = xmalloc(sizeof(struct dictAccess));
 		a->type = DICT_USER;
 		a->spec = (yyvsp[0].token).string;
 		(yyval.access) = a;
 	     }
-#line 1973 "y.tab.c"
+#line 1977 "y.tab.c"
     break;
 
   case 54: /* $@1: %empty  */
-#line 391 "servparse.y"
+#line 395 "servparse.y"
            {
 	      db = xmalloc(sizeof(struct dictDatabase));
 	      memset( db, 0, sizeof(struct dictDatabase));
 	      db->databaseName = (yyvsp[0].token).string;
 	      db->normal_db    = 1;
 	   }
-#line 1984 "y.tab.c"
+#line 1988 "y.tab.c"
     break;
 
   case 55: /* Database: TOKEN_DATABASE TOKEN_STRING $@1 '{' SpecList '}'  */
-#line 397 "servparse.y"
+#line 401 "servparse.y"
                             { (yyval.db) = db; }
-#line 1990 "y.tab.c"
+#line 1994 "y.tab.c"
     break;
 
   case 56: /* $@2: %empty  */
-#line 400 "servparse.y"
+#line 404 "servparse.y"
            {
 	      db = xmalloc(sizeof(struct dictDatabase));
 	      memset( db, 0, sizeof(struct dictDatabase));
 	      db->databaseName = (yyvsp[0].token).string;
 	      db->virtual_db   = 1;
 	   }
-#line 2001 "y.tab.c"
+#line 2005 "y.tab.c"
     break;
 
   case 57: /* Database: TOKEN_DATABASE_VIRTUAL TOKEN_STRING $@2 '{' SpecList_virtual '}'  */
-#line 406 "servparse.y"
+#line 410 "servparse.y"
                                     { (yyval.db) = db; }
-#line 2007 "y.tab.c"
+#line 2011 "y.tab.c"
     break;
 
   case 58: /* $@3: %empty  */
-#line 409 "servparse.y"
+#line 413 "servparse.y"
            {
 	      db = xmalloc(sizeof(struct dictDatabase));
 	      memset( db, 0, sizeof(struct dictDatabase));
 	      db->databaseName = (yyvsp[0].token).string;
 	      db->plugin_db    = 1;
 	   }
-#line 2018 "y.tab.c"
+#line 2022 "y.tab.c"
     break;
 
   case 59: /* Database: TOKEN_DATABASE_PLUGIN TOKEN_STRING $@3 '{' SpecList_plugin '}'  */
-#line 415 "servparse.y"
+#line 419 "servparse.y"
                                    { (yyval.db) = db; }
-#line 2024 "y.tab.c"
+#line 2028 "y.tab.c"
     break;
 
   case 60: /* $@4: %empty  */
-#line 418 "servparse.y"
+#line 422 "servparse.y"
            {
 	      db = xmalloc (sizeof (struct dictDatabase));
 	      memset (db, 0, sizeof (struct dictDatabase));
 	      db->databaseName = (yyvsp[0].token).string;
 	      db->mime_db      = 1;
 	   }
-#line 2035 "y.tab.c"
+#line 2039 "y.tab.c"
     break;
 
   case 61: /* Database: TOKEN_DATABASE_MIME TOKEN_STRING $@4 '{' SpecList_mime '}'  */
-#line 424 "servparse.y"
+#line 428 "servparse.y"
                                  { (yyval.db) = db; }
-#line 2041 "y.tab.c"
+#line 2045 "y.tab.c"
     break;
 
   case 62: /* Database: TOKEN_DATABASE_EXIT  */
-#line 427 "servparse.y"
+#line 431 "servparse.y"
            {
 	      db = xmalloc(sizeof(struct dictDatabase));
 	      memset( db, 0, sizeof(struct dictDatabase));
@@ -2050,119 +2054,119 @@ yyreduce:
 	      db -> exit_db       = 1;
 	      (yyval.db) = db;
 	   }
-#line 2054 "y.tab.c"
+#line 2058 "y.tab.c"
     break;
 
   case 67: /* Spec_virtual: TOKEN_DATABASE_LIST TOKEN_STRING  */
-#line 443 "servparse.y"
+#line 447 "servparse.y"
                                              { SET(database_list,(yyvsp[-1].token),(yyvsp[0].token));}
-#line 2060 "y.tab.c"
+#line 2064 "y.tab.c"
     break;
 
   case 85: /* Spec_plugin: TOKEN_PLUGIN TOKEN_STRING  */
-#line 469 "servparse.y"
+#line 473 "servparse.y"
                                       { SET(pluginFilename,(yyvsp[-1].token),(yyvsp[0].token));}
-#line 2066 "y.tab.c"
+#line 2070 "y.tab.c"
     break;
 
   case 86: /* Spec_plugin: TOKEN_DATA TOKEN_STRING  */
-#line 470 "servparse.y"
+#line 474 "servparse.y"
                                       { SET(plugin_data,(yyvsp[-1].token),(yyvsp[0].token));}
-#line 2072 "y.tab.c"
+#line 2076 "y.tab.c"
     break;
 
   case 106: /* Spec__access: Access  */
-#line 497 "servparse.y"
+#line 501 "servparse.y"
      {  db->acl = (yyvsp[0].list);  }
-#line 2078 "y.tab.c"
+#line 2082 "y.tab.c"
     break;
 
   case 107: /* Spec__data: TOKEN_DATA TOKEN_STRING  */
-#line 500 "servparse.y"
+#line 504 "servparse.y"
      {	SET(dataFilename,(yyvsp[-1].token),(yyvsp[0].token));  }
-#line 2084 "y.tab.c"
+#line 2088 "y.tab.c"
     break;
 
   case 108: /* Spec__index: TOKEN_INDEX TOKEN_STRING  */
-#line 503 "servparse.y"
+#line 507 "servparse.y"
      {  SET(indexFilename,(yyvsp[-1].token),(yyvsp[0].token));  }
-#line 2090 "y.tab.c"
+#line 2094 "y.tab.c"
     break;
 
   case 109: /* Spec__index_suffix: TOKEN_INDEX_SUFFIX TOKEN_STRING  */
-#line 506 "servparse.y"
+#line 510 "servparse.y"
      {  SET(indexsuffixFilename,(yyvsp[-1].token),(yyvsp[0].token)); }
-#line 2096 "y.tab.c"
+#line 2100 "y.tab.c"
     break;
 
   case 110: /* Spec__index_word: TOKEN_INDEX_WORD TOKEN_STRING  */
-#line 509 "servparse.y"
+#line 513 "servparse.y"
      {  SET(indexwordFilename,(yyvsp[-1].token),(yyvsp[0].token));  }
-#line 2102 "y.tab.c"
+#line 2106 "y.tab.c"
     break;
 
   case 111: /* Spec__filter: TOKEN_FILTER TOKEN_STRING  */
-#line 512 "servparse.y"
+#line 516 "servparse.y"
      {  SET(filter,(yyvsp[-1].token),(yyvsp[0].token));  }
-#line 2108 "y.tab.c"
+#line 2112 "y.tab.c"
     break;
 
   case 112: /* Spec__prefilter: TOKEN_PREFILTER TOKEN_STRING  */
-#line 515 "servparse.y"
+#line 519 "servparse.y"
      {  SET(prefilter,(yyvsp[-1].token),(yyvsp[0].token));  }
-#line 2114 "y.tab.c"
+#line 2118 "y.tab.c"
     break;
 
   case 113: /* Spec__postfilter: TOKEN_POSTFILTER TOKEN_STRING  */
-#line 518 "servparse.y"
+#line 522 "servparse.y"
      {  SET(postfilter,(yyvsp[-1].token),(yyvsp[0].token));  }
-#line 2120 "y.tab.c"
+#line 2124 "y.tab.c"
     break;
 
   case 114: /* Spec__name: TOKEN_NAME TOKEN_STRING  */
-#line 521 "servparse.y"
+#line 525 "servparse.y"
      {  SET(databaseShort,(yyvsp[-1].token),(yyvsp[0].token));  }
-#line 2126 "y.tab.c"
+#line 2130 "y.tab.c"
     break;
 
   case 115: /* Spec__info: TOKEN_INFO TOKEN_STRING  */
-#line 524 "servparse.y"
+#line 528 "servparse.y"
      {  SET(databaseInfo,(yyvsp[-1].token),(yyvsp[0].token));  }
-#line 2132 "y.tab.c"
+#line 2136 "y.tab.c"
     break;
 
   case 116: /* Spec__invisible: TOKEN_INVISIBLE  */
-#line 527 "servparse.y"
+#line 531 "servparse.y"
      {  db->invisible = 1;  }
-#line 2138 "y.tab.c"
+#line 2142 "y.tab.c"
     break;
 
   case 117: /* Spec__disable_strat: TOKEN_DISABLE_STRAT TOKEN_STRING  */
-#line 530 "servparse.y"
+#line 534 "servparse.y"
      {  dict_disable_strat (db, (yyvsp[0].token).string);  }
-#line 2144 "y.tab.c"
+#line 2148 "y.tab.c"
     break;
 
   case 118: /* Spec__default_strat: TOKEN_DEFAULT_STRAT TOKEN_STRING  */
-#line 533 "servparse.y"
+#line 537 "servparse.y"
      {  db -> default_strategy = lookup_strategy_ex ((yyvsp[0].token).string);  }
-#line 2150 "y.tab.c"
+#line 2154 "y.tab.c"
     break;
 
   case 119: /* Spec__dbname_mime: TOKEN_MIME_DBNAME TOKEN_STRING  */
-#line 536 "servparse.y"
+#line 540 "servparse.y"
      {  SET(mime_mimeDbname,(yyvsp[-1].token),(yyvsp[0].token));  }
-#line 2156 "y.tab.c"
+#line 2160 "y.tab.c"
     break;
 
   case 120: /* Spec__dbname_nomime: TOKEN_NOMIME_DBNAME TOKEN_STRING  */
-#line 539 "servparse.y"
+#line 543 "servparse.y"
      {  SET(mime_nomimeDbname,(yyvsp[-1].token),(yyvsp[0].token));  }
-#line 2162 "y.tab.c"
+#line 2166 "y.tab.c"
     break;
 
 
-#line 2166 "y.tab.c"
+#line 2170 "y.tab.c"
 
       default: break;
     }
